/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.net.protocol.classpath;

import java.io.IOException;
import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.URLConnection;

public class ClassPathURLConnection extends URLConnection {

	private Class<?> targetClass;

//	private InputStream is;

	public ClassPathURLConnection(final URL url) {
		super(url);
		this.targetClass = getClass();
	}

	public ClassPathURLConnection(final URL url, final Class<?> targetClass) {
		super(url);
		this.targetClass = targetClass;
	}

	public Class<?> getTargetClass() {
		return targetClass;
	}

	@Override
	public void connect() throws IOException {
	}

	@Override
	public InputStream getInputStream() throws IOException {
		try {
			final URI uri = url.toURI();
			final String resourceName = uri.getPath(); // url.getFile();
			return getTargetClass().getResourceAsStream(resourceName);
		} catch (URISyntaxException urisex) {
			throw new IOException(urisex);
		}
	}

}
