/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.testing.net;

import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.Validate;

public class URLUtils {

	private URLUtils() {

	}

	public static URL getURL(String url) {
		try {
			return new URL(url);
		} catch (MalformedURLException murlex) {
			throw new RuntimeException(murlex);
		}
	}

	public static String getContentAsString(final URL url) throws IOException {
		return getContentAsString(url, "UTF-8");

	}

	public static String getContentAsString(final URL url,
			final String draftEncoding) throws IOException {
		Validate.notNull(url, "URL must not be null.");
		final String encoding = draftEncoding == null ? "UTF-8" : draftEncoding;
		InputStream inputStream = null;
		try {
			final URLConnection connection = url.openConnection();
			inputStream = connection.getInputStream();
			return IOUtils.toString(inputStream, encoding);
		} finally {
			IOUtils.closeQuietly(inputStream);
		}
	}

}
