/**
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.disy.legato.testing.server.testing;

import static org.junit.Assert.*;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import net.disy.legato.testing.server.IWebServerEnvironment;
import net.disy.legato.testing.server.IWebServerEnvironmentFactory;
import net.disy.legato.testing.server.jetty.PropertiesJettyWebServerEnvironmentFactory;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.After;

@SuppressWarnings("nls")
public abstract class AbstractMultipleWebServerEnvironmentTest {

  protected final Log log = LogFactory.getLog(getClass());

  protected List<IWebServerEnvironment> webServers = new ArrayList<IWebServerEnvironment>();

  @After
  public void stopWebServers() throws IOException, Exception {
    log.debug("Stopping web servers begin...");
    for (IWebServerEnvironment server : webServers) {
      stopWebServer(server);
    }
    log.debug("Stopping web servers end.");
  }

  protected IWebServerEnvironment startWebServer(String propertiesFilePath)
      throws IOException,
      Exception {
    IWebServerEnvironmentFactory factory = PropertiesJettyWebServerEnvironmentFactory.getInstance(
        new File("."), //$NON-NLS-1$
        propertiesFilePath);
    IWebServerEnvironment webServerEnvironment = factory.createWebServerEnvironment();
    webServerEnvironment.start();
    assertTrue(webServerEnvironment.isStarted());
    webServers.add(webServerEnvironment);
    return webServerEnvironment;
  }

  protected void stopWebServer(IWebServerEnvironment server) throws IOException, Exception {
    if (server != null && server.isStarted()) {
      server.stop();
    }
  }

}
